tonalitytools.chord_class_cardinality_to_extent
===============================================

.. autofunction:: abjad.tools.tonalitytools.chord_class_cardinality_to_extent.chord_class_cardinality_to_extent
